# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2020/12/29 19:28
:LastEditTime: 2020/12/29 19:28
:LastEditors: SunYiTan
:Description: 玩家操作信息
"""


class ActionInfoVO:

    def __init__(self):
        self.action_id = 0
        self.doll_id = 0
        self.parama = ""
        self.paramb = ""
        self.paramc = ""
        self.paramd = ""
